@@ -1,4 +1,4 @@
-# $Id: twitter.py 1383 2015-10-31 15:59:53Z mwall $
+# $Id: twitter.py 1491 2016-05-15 23:00:28Z mwall $
 # Copyright 2014 Matthew Wall
 """
 Tweet weather data
@@ -84,7 +84,7 @@ from weeutil.weeutil import to_bool, accumulateLeaves
 
 from twython import Twython, TwythonError, TwythonAuthError, TwythonRateLimitError
 
-VERSION = "0.11"
+VERSION = "0.12"
 
 if weewx.__version__ < "3":
     raise weewx.UnsupportedFeature("weewx 3 is required, found %s" %
@@ -257,7 +257,7 @@ class TwitterThread(weewx.restx.RESTThread):
                 elif record[obs] is None:
                     newstr = self.format_None
                 elif obs == 'windDir' and fmt.lower() == 'ord':
-                    newstr = dir_to_ord(record[obs], self.ordinals)
+                    newstr = _dir_to_ord(record[obs], self.ordinals)
                 else:
                     newstr = fmt % record[obs]
                 msg = msg.replace(oldstr, newstr)
